package events;

import board.IBoard;
import objects.Empty;
import objects.Token;

import java.util.ArrayList;

public class Bomb extends RandomEvent {
    @Override
    public void act(IBoard b) {
        int x = random.nextInt(b.getWidth());
        int y = b.getTopObject(x);
        for (ArrayList<Integer> list : generateSquare(b, x, y, random.nextInt(2) + 1)) {
            b.set(list.get(0), list.get(1), new Empty());
        }
    }

    /**
     * Gets all locations in a square a range from a point.
     *
     * @param b     A board
     * @param x     The x index of the starting point
     * @param y     The y index of the starting point
     * @param range The range of the square
     * @return      A list of lists of integers
     */
    private ArrayList<ArrayList<Integer>> generateSquare(IBoard b, int x, int y, int range) {
        ArrayList<ArrayList<Integer>> locations = new ArrayList<>();
        for (int i = x - range; i <= x + range; i++) {
            for (int j = y - range; j <= y + range; j++) {
                if (i >= 0 && i < b.getWidth() && j >= 0 && j < b.getHeight() && b.get(i, j) instanceof Token) {
                    ArrayList<Integer> coords = new ArrayList<>();
                    coords.add(i);
                    coords.add(j);
                    locations.add(coords);
                }
            }
        }
        return locations;
    }

    @Override
    public String announcement() {
        return "A bomb just exploded!";
    }
}
