package events;

import board.IBoard;

import java.util.Random;

/**
 * Contains basic probability methods usable by all random events.
 */
public abstract class RandomEvent implements IRandomEvent {
    final Random random = new Random();

    /**
     * Flips a coin, and acts if it comes out as head.
     *
     * @param b The board to act on
     * @return  True if somehting happened. False otherwise
     */
    public boolean flipCoin(IBoard b) {
        if (random.nextInt(2) > 0) {
            act(b);
            return true;
        }
        return false;
    }

    /**
     * Rolls n die, and acts if all die got a "6".
     *
     * @param b The board to act on
     * @param n The number of die
     * @return  True if something happened. False otherwise
     */
    public boolean rollDie(IBoard b, int n) {
        if (random.nextInt((int)Math.pow(6, n)) < 1) {
            act(b);
            return true;
        }
        return false;
    }

    public abstract void act(IBoard b);
}
